@@ -19,77 +19,6 @@ __all__ = [
 ]
 
 
-@not_implemented_for("directed")
-def _tree_center(G):
-    """Returns the center of an undirected tree graph.
-
-    The center of a tree consists of nodes that minimize the maximum eccentricity.
-    That is, these nodes minimize the maximum distance to all other nodes.
-    This implementation currently only works for unweighted edges.
-
-    If the input graph is not a tree, results are not guaranteed to be correct and while
-    some non-trees will raise a ``NetworkXError`` not all non-trees will be discovered.
-    Thus, this function should not be used if caller is unsure whether the input graph
-    is a tree. Use ``networkx.is_tree(G)`` to check.
-
-    Parameters
-    ----------
-    G : NetworkX graph
-        A tree graph (undirected, acyclic graph).
-
-    Returns
-    -------
-    center : list
-        A list of nodes in the center of the tree. This could be one or two nodes.
-
-    Raises
-    ------
-    NetworkXError
-        If algorithm detects input graph is not a tree. There is no guarantee
-        this error will always raise if a non-tree is passed.
-
-    Notes
-    -----
-    This algorithm iteratively removes leaves (nodes with degree 1) from the tree until
-    there are only 1 or 2 nodes left. The remaining nodes form the center of the tree.
-
-    This algorithm's time complexity is O(N) where N is the number of nodes in the tree.
-
-    Examples
-    --------
-    >>> G = nx.Graph([(1, 2), (1, 3), (2, 4), (2, 5)])
-    >>> _tree_center(G)
-    [1, 2]
-
-    >>> G = nx.Graph([(1, 2), (2, 3), (3, 4), (4, 5)])
-    >>> _tree_center(G)
-    [3]
-    """
-    center_candidates_degree = dict(G.degree)
-    leaves = {node for node, degree in center_candidates_degree.items() if degree == 1}
-
-    # It's better to fail than an infinite loop, so check leaves to ensure progress
-    while len(center_candidates_degree) > 2 and leaves:
-        new_leaves = set()
-        for leaf in leaves:
-            del center_candidates_degree[leaf]
-            for neighbor in G.neighbors(leaf):
-                if neighbor not in center_candidates_degree:
-                    continue
-                center_candidates_degree[neighbor] -= 1
-                if center_candidates_degree[neighbor] == 1:
-                    new_leaves.add(neighbor)
-        leaves = new_leaves
-
-    if not leaves and len(center_candidates_degree) >= 2:
-        # We detected graph is not a tree. This check does not cover all cases.
-        # For example, it does not cover the case where we have two islands (A-B) and (B-C)
-        # where we might eliminate (B-C) leaves and return [A, B] as centers.
-        raise nx.NetworkXError("Input graph is not a tree")
-
-    return list(center_candidates_degree)
-
-
 def _extrema_bounding(G, compute="diameter", weight=None):
     """Compute requested extreme distance metric of undirected graph G
 
@@ -747,13 +676,15 @@ def center(G, e=None, usebounds=False, weight=None):
 
     See Also
     --------
+    :func:`~networkx.algorithms.tree.distance_measures.center` : tree center
     barycenter
     periphery
+    :func:`~networkx.algorithms.tree.distance_measures.centroid` : tree centroid
     """
     if usebounds is True and e is None and not G.is_directed():
         return _extrema_bounding(G, compute="center", weight=weight)
     if e is None and weight is None and not G.is_directed() and nx.is_tree(G):
-        return _tree_center(G)
+        return nx.tree.center(G)
     if e is None:
         e = eccentricity(G, weight=weight)
     radius = min(e.values())
@@ -815,7 +746,12 @@ def barycenter(G, weight=None, attr=None, sp=None):
     --------
     center
     periphery
+    :func:`~networkx.algorithms.tree.distance_measures.centroid` : tree centroid
     """
+    if weight is None and attr is None and sp is None:
+        if not G.is_directed() and nx.is_tree(G):
+            return nx.tree.centroid(G)
+
     if sp is None:
         sp = nx.shortest_path_length(G, weight=weight)
     else:
@@ -1149,7 +1085,7 @@ def kemeny_constant(G, *, weight=None):
     with np.errstate(divide="ignore"):
         diags_sqrt = 1.0 / np.sqrt(diags)
     diags_sqrt[np.isinf(diags_sqrt)] = 0
-    DH = sp.sparse.csr_array(sp.sparse.spdiags(diags_sqrt, 0, m, n, format="csr"))
+    DH = sp.sparse.dia_array((diags_sqrt, 0), shape=(m, n)).tocsr()
     H = DH @ (A @ DH)
 
     # Compute eigenvalues of H
