@@ -1,38 +1,11 @@
 """Generators for classes of graphs used in studying social networks."""
+
 import itertools
 import math
+
 import networkx as nx
 from networkx.utils import py_random_state
 
-# Accommodates for both SciPy and non-SciPy implementations..
-try:
-    from scipy.special import zeta as _zeta
-
-    def zeta(x, q, tolerance):
-        return _zeta(x, q)
-
-
-except ImportError:
-
-    def zeta(x, q, tolerance):
-        """The Hurwitz zeta function, or the Riemann zeta function of two
-        arguments.
-
-        ``x`` must be greater than one and ``q`` must be positive.
-
-        This function repeatedly computes subsequent partial sums until
-        convergence, as decided by ``tolerance``.
-        """
-        z = 0
-        z_prev = -float("inf")
-        k = 0
-        while abs(z - z_prev) > tolerance:
-            z_prev = z
-            z += 1 / ((k + q) ** x)
-            k += 1
-        return z
-
-
 __all__ = [
     "caveman_graph",
     "connected_caveman_graph",
@@ -47,6 +20,7 @@ __all__ = [
 ]
 
 
+@nx._dispatchable(graphs=None, returns_graph=True)
 def caveman_graph(l, k):
     """Returns a caveman graph of `l` cliques of size `k`.
 
@@ -93,6 +67,7 @@ def caveman_graph(l, k):
     return G
 
 
+@nx._dispatchable(graphs=None, returns_graph=True)
 def connected_caveman_graph(l, k):
     """Returns a connected caveman graph of `l` cliques of size `k`.
 
@@ -136,7 +111,7 @@ def connected_caveman_graph(l, k):
     """
     if k < 2:
         raise nx.NetworkXError(
-            "The size of cliques in a connected caveman graph " "must be at least 2."
+            "The size of cliques in a connected caveman graph must be at least 2."
         )
 
     G = nx.caveman_graph(l, k)
@@ -147,6 +122,7 @@ def connected_caveman_graph(l, k):
 
 
 @py_random_state(3)
+@nx._dispatchable(graphs=None, returns_graph=True)
 def relaxed_caveman_graph(l, k, p, seed=None):
     """Returns a relaxed caveman graph.
 
@@ -160,7 +136,7 @@ def relaxed_caveman_graph(l, k, p, seed=None):
     k : int
       Size of cliques
     p : float
-      Probabilty of rewiring each edge.
+      Probability of rewiring each edge.
     seed : integer, random_state, or None (default)
         Indicator of random number generation state.
         See :ref:`Randomness<randomness>`.
@@ -187,7 +163,7 @@ def relaxed_caveman_graph(l, k, p, seed=None):
     """
     G = nx.caveman_graph(l, k)
     nodes = list(G)
-    for (u, v) in G.edges():
+    for u, v in G.edges():
         if seed.random() < p:  # rewire the edge
             x = seed.choice(nodes)
             if G.has_edge(u, x):
@@ -198,6 +174,7 @@ def relaxed_caveman_graph(l, k, p, seed=None):
 
 
 @py_random_state(3)
+@nx._dispatchable(graphs=None, returns_graph=True)
 def random_partition_graph(sizes, p_in, p_out, seed=None, directed=False):
     """Returns the random partition graph with a partition of sizes.
 
@@ -276,6 +253,7 @@ def random_partition_graph(sizes, p_in, p_out, seed=None, directed=False):
 
 
 @py_random_state(4)
+@nx._dispatchable(graphs=None, returns_graph=True)
 def planted_partition_graph(l, k, p_in, p_out, seed=None, directed=False):
     """Returns the planted l-partition graph.
 
@@ -308,7 +286,7 @@ def planted_partition_graph(l, k, p_in, p_out, seed=None, directed=False):
     Raises
     ------
     NetworkXError
-      If p_in,p_out are not in [0,1] or
+      If `p_in`, `p_out` are not in `[0, 1]`
 
     Examples
     --------
@@ -331,6 +309,7 @@ def planted_partition_graph(l, k, p_in, p_out, seed=None, directed=False):
 
 
 @py_random_state(6)
+@nx._dispatchable(graphs=None, returns_graph=True)
 def gaussian_random_partition_graph(n, s, v, p_in, p_out, directed=False, seed=None):
     """Generate a Gaussian random partition graph.
 
@@ -348,7 +327,7 @@ def gaussian_random_partition_graph(n, s, v, p_in, p_out, directed=False, seed=N
     v : float
       Shape parameter. The variance of cluster size distribution is s/v.
     p_in : float
-      Probabilty of intra cluster connection.
+      Probability of intra cluster connection.
     p_out : float
       Probability of inter cluster connection.
     directed : boolean, optional default=False
@@ -395,7 +374,7 @@ def gaussian_random_partition_graph(n, s, v, p_in, p_out, directed=False, seed=N
     assigned = 0
     sizes = []
     while True:
-        size = int(seed.gauss(s, float(s) / v + 0.5))
+        size = int(seed.gauss(s, s / v + 0.5))
         if size < 1:  # how to handle 0 or negative sizes?
             continue
         if assigned + size >= n:
@@ -406,6 +385,7 @@ def gaussian_random_partition_graph(n, s, v, p_in, p_out, directed=False, seed=N
     return random_partition_graph(sizes, p_in, p_out, seed=seed, directed=directed)
 
 
+@nx._dispatchable(graphs=None, returns_graph=True)
 def ring_of_cliques(num_cliques, clique_size):
     """Defines a "ring of cliques" graph.
 
@@ -445,7 +425,7 @@ def ring_of_cliques(num_cliques, clique_size):
     simply adds the link without removing any link from the cliques.
     """
     if num_cliques < 2:
-        raise nx.NetworkXError("A ring of cliques must have at least " "two cliques")
+        raise nx.NetworkXError("A ring of cliques must have at least two cliques")
     if clique_size < 2:
         raise nx.NetworkXError("The cliques must have at least two nodes")
 
@@ -461,6 +441,7 @@ def ring_of_cliques(num_cliques, clique_size):
     return G
 
 
+@nx._dispatchable(graphs=None, returns_graph=True)
 def windmill_graph(n, k):
     """Generate a windmill graph.
     A windmill graph is a graph of `n` cliques each of size `k` that are all
@@ -514,6 +495,7 @@ def windmill_graph(n, k):
 
 
 @py_random_state(3)
+@nx._dispatchable(graphs=None, returns_graph=True)
 def stochastic_block_model(
     sizes, p, nodelist=None, seed=None, directed=False, selfloops=False, sparse=True
 ):
@@ -570,13 +552,11 @@ def stochastic_block_model(
     >>> H = nx.quotient_graph(g, g.graph["partition"], relabel=True)
     >>> for v in H.nodes(data=True):
     ...     print(round(v[1]["density"], 3))
-    ...
     0.245
     0.348
     0.405
     >>> for v in H.edges(data=True):
     ...     print(round(1.0 * v[2]["weight"] / (sizes[v[0]] * sizes[v[1]]), 3))
-    ...
     0.051
     0.022
     0.07
@@ -619,7 +599,7 @@ def stochastic_block_model(
         if len(nodelist) != len(set(nodelist)):
             raise nx.NetworkXException("nodelist contains duplicate.")
     else:
-        nodelist = range(0, sum(sizes))
+        nodelist = range(sum(sizes))
 
     # Setup the graph conditionally to the directed switch.
     block_range = range(len(sizes))
@@ -630,10 +610,10 @@ def stochastic_block_model(
         g = nx.Graph()
         block_iter = itertools.combinations_with_replacement(block_range, 2)
     # Split nodelist in a partition (list of sets).
-    size_cumsum = [sum(sizes[0:x]) for x in range(0, len(sizes) + 1)]
+    size_cumsum = [sum(sizes[0:x]) for x in range(len(sizes) + 1)]
     g.graph["partition"] = [
         set(nodelist[size_cumsum[x] : size_cumsum[x + 1]])
-        for x in range(0, len(size_cumsum) - 1)
+        for x in range(len(size_cumsum) - 1)
     ]
     # Setup nodes and graph name
     for block_id, nodes in enumerate(g.graph["partition"]):
@@ -725,9 +705,34 @@ def _powerlaw_sequence(gamma, low, high, condition, length, max_iters, seed):
     raise nx.ExceededMaxIterations("Could not create power law sequence")
 
 
-# TODO Needs documentation.
+def _hurwitz_zeta(x, q, tolerance):
+    """The Hurwitz zeta function, or the Riemann zeta function of two arguments.
+
+    ``x`` must be greater than one and ``q`` must be positive.
+
+    This function repeatedly computes subsequent partial sums until
+    convergence, as decided by ``tolerance``.
+    """
+    z = 0
+    z_prev = -float("inf")
+    k = 0
+    while abs(z - z_prev) > tolerance:
+        z_prev = z
+        z += 1 / ((k + q) ** x)
+        k += 1
+    return z
+
+
 def _generate_min_degree(gamma, average_degree, max_degree, tolerance, max_iters):
     """Returns a minimum degree from the given average degree."""
+    # Defines zeta function whether or not Scipy is available
+    try:
+        from scipy.special import zeta
+    except ImportError:
+
+        def zeta(x, q):
+            return _hurwitz_zeta(x, q, tolerance)
+
     min_deg_top = max_degree
     min_deg_bot = 1
     min_deg_mid = (min_deg_top - min_deg_bot) / 2 + min_deg_bot
@@ -738,7 +743,7 @@ def _generate_min_degree(gamma, average_degree, max_degree, tolerance, max_iters
             raise nx.ExceededMaxIterations("Could not match average_degree")
         mid_avg_deg = 0
         for x in range(int(min_deg_mid), max_degree + 1):
-            mid_avg_deg += (x ** (-gamma + 1)) / zeta(gamma, min_deg_mid, tolerance)
+            mid_avg_deg += (x ** (-gamma + 1)) / zeta(gamma, min_deg_mid)
         if mid_avg_deg > average_degree:
             min_deg_top = min_deg_mid
             min_deg_mid = (min_deg_top - min_deg_bot) / 2 + min_deg_bot
@@ -802,6 +807,7 @@ def _generate_communities(degree_seq, community_sizes, mu, max_iters, seed):
 
 
 @py_random_state(11)
+@nx._dispatchable(graphs=None, returns_graph=True)
 def LFR_benchmark_graph(
     n,
     tau1,
@@ -829,9 +835,9 @@ def LFR_benchmark_graph(
           case a suitable minimum degree will be found.
 
        ``max_degree`` can also be specified, otherwise it will be set to
-       ``n``. Each node *u* will have `\mu \mathrm{deg}(u)` edges
-       joining it to nodes in communities other than its own and `(1 -
-       \mu) \mathrm{deg}(u)` edges joining it to nodes in its own
+       ``n``. Each node *u* will have $\mu \mathrm{deg}(u)$ edges
+       joining it to nodes in communities other than its own and $(1 -
+       \mu) \mathrm{deg}(u)$ edges joining it to nodes in its own
        community.
     2) Generate community sizes according to a power law distribution
        with exponent ``tau2``. If ``min_community`` and
@@ -840,12 +846,12 @@ def LFR_benchmark_graph(
        are generated until the sum of their sizes equals ``n``.
     3) Each node will be randomly assigned a community with the
        condition that the community is large enough for the node's
-       intra-community degree, `(1 - \mu) \mathrm{deg}(u)` as
+       intra-community degree, $(1 - \mu) \mathrm{deg}(u)$ as
        described in step 2. If a community grows too large, a random node
        will be selected for reassignment to a new community, until all
        nodes have been assigned a community.
-    4) Each node *u* then adds `(1 - \mu) \mathrm{deg}(u)`
-       intra-community edges and `\mu \mathrm{deg}(u)` inter-community
+    4) Each node *u* then adds $(1 - \mu) \mathrm{deg}(u)$
+       intra-community edges and $\mu \mathrm{deg}(u)$ inter-community
        edges.
 
     Parameters
@@ -862,7 +868,7 @@ def LFR_benchmark_graph(
         created graph. This value must be strictly greater than one.
 
     mu : float
-        Fraction of intra-community edges incident to each node. This
+        Fraction of inter-community edges incident to each node. This
         value must be in the interval [0, 1].
 
     average_degree : float
@@ -981,7 +987,7 @@ def LFR_benchmark_graph(
     .. [1] "Benchmark graphs for testing community detection algorithms",
            Andrea Lancichinetti, Santo Fortunato, and Filippo Radicchi,
            Phys. Rev. E 78, 046110 2008
-    .. [2] http://santo.fortunato.googlepages.com/inthepress2
+    .. [2] https://www.santofortunato.net/resources
 
     """
     # Perform some basic parameter validation.
@@ -999,7 +1005,7 @@ def LFR_benchmark_graph(
         raise nx.NetworkXError("max_degree must be in the interval (0, n]")
     if not ((min_degree is None) ^ (average_degree is None)):
         raise nx.NetworkXError(
-            "Must assign exactly one of min_degree and" " average_degree"
+            "Must assign exactly one of min_degree and average_degree"
         )
     if min_degree is None:
         min_degree = _generate_min_degree(
